@@ -7,12 +7,12 @@ DefaultThemes = {
         Style('parenthesis_cur', 'White', 'Blue'),
         Style('parenthesis_match', 'Red', 'Yellow'),
 
-        Style('keyword', 'Magenta', 'default'),
-        Style('constant', 'Red', 'default'),
-        Style('directive', 'Orange', 'default'),
-        Style('comment', 'Cyan', 'default'),
-        Style('string', 'Blue', 'default'),
-        Style('number', 'Green', 'default'),
+        Style('keyword', 'Magenta', None),
+        Style('constant', 'Red', None),
+        Style('directive', 'Orange', None),
+        Style('comment', 'Cyan', None),
+        Style('string', 'Blue', None),
+        Style('number', 'Green', None),
 
         Overlay('cursor_row', None, 'Base02'),
         Overlay('breakpoint', None, 'Base02'),
